#!/bin/bash

source $3
bam1=$(echo $1 | awk -F ".bam" '{print $1}')
bam2=$(echo $2 | awk -F ".bam" '{print $1}')
partition=$4

if [[ ${#bam1} != 0 ]] && [[ ${#bam2} != 0 ]]; then
	if [[ $preprocess == '1' ]]; then
		if [[ $startfrom == 'realign' ]]; then
			echo "1. GATK RealignerTargetCreator"
			starting=`date +%s`;
			knownsites=''
			for i in ${known[@]}; do
				knownsites+=" -known "$i
			done
			eval "cat $partition | parallel --no-notice -j "$cores" \"java -XX:+UseParallelGC -XX:ParallelGCThreads="$ParallelGCThreads" -Xmx"$Xmx" -jar "$gatk" -R "$ref" -T RealignerTargetCreator "$knownsites" -o "$bam1".{}.intervals -I "$bam1".bam -rf NotPrimaryAlignment -L {}\" &"
			wait
			eval "cat $partition | parallel --no-notice -j "$cores" \"java -XX:+UseParallelGC -XX:ParallelGCThreads="$ParallelGCThreads" -Xmx"$Xmx" -jar "$gatk" -R "$ref" -T RealignerTargetCreator "$knownsites" -o "$bam2".{}.intervals -I "$bam2".bam -rf NotPrimaryAlignment -L {}\" &"
			wait
			end=`date +%s`;
			echo "Time elapsed for GATK RealignerTargetCreator = $(($end-$starting)) seconds"
			echo ""
		fi
		if [[ $startfrom == 'realign' || $startfrom == 'indelrealign' ]]; then
			echo "2. GATK IndelRealigner"
			starting=`date +%s`;
			eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e $bam1.{}.intervals ]; then java -XX:+UseParallelGC -XX:ParallelGCThreads="$ParallelGCThreads" -Xmx"$Xmx" -jar "$gatk" -R "$ref" -T IndelRealigner "$knownsites" -o "$bam1".{}.real.bam -I "$bam1".bam -rf NotPrimaryAlignment -L {} -targetIntervals "$bam1".{}.intervals; fi\" &"
			wait
			eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e $bam2.{}.intervals ]; then java -XX:+UseParallelGC -XX:ParallelGCThreads="$ParallelGCThreads" -Xmx"$Xmx" -jar "$gatk" -R "$ref" -T IndelRealigner "$knownsites" -o "$bam2".{}.real.bam -I "$bam2".bam -rf NotPrimaryAlignment -L {} -targetIntervals "$bam2".{}.intervals; fi\" &"
			wait
			#rm -f "$bam1".*.intervals; #cleanup
			#rm -f "$bam2".*.intervals; #cleanup
			end=`date +%s`;
	        	echo "Time elapsed for GATK IndelRealigner = $(($end-$starting)) seconds"
			echo ""
		fi
		if [[ $startfrom == 'realign' || $startfrom == 'indelrealign' || $startfrom == 'baserecal' ]]; then
			echo "3. GATK BaseRecalibrator"
			starting=`date +%s`;
			knownsites=''
			for i in ${known[@]}; do
	                        knownsites+=" -knownSites "$i
	                done
			for i in ${dbsnp[@]}; do
				knownsites+=" -knownSites "$i
			done
			eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e $bam1.{}.real.bam ]; then java -XX:+UseParallelGC -XX:ParallelGCThreads="$ParallelGCThreads" -Xmx"$Xmx" -jar "$gatk" -R "$ref" -T BaseRecalibrator -nct "$nct" "$knownsites" -o "$bam1".{}.recal.grp -I "$bam1".{}.real.bam -rf NotPrimaryAlignment -L {}; fi\" &"
			wait
			eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e $bam2.{}.real.bam ]; then java -XX:+UseParallelGC -XX:ParallelGCThreads="$ParallelGCThreads" -Xmx"$Xmx" -jar "$gatk" -R "$ref" -T BaseRecalibrator -nct "$nct" "$knownsites" -o "$bam2".{}.recal.grp -I "$bam2".{}.real.bam -rf NotPrimaryAlignment -L {}; fi\" &"
			wait
			end=`date +%s`;
	        	echo "Time elapsed for GATK BaseRecalibrator = $(($end-$starting)) seconds"
			echo ""
		fi
		if [[ $startfrom == 'realign' || $startfrom == 'indelrealign' || $startfrom == 'baserecal' || $startfrom == 'printreads' ]]; then
			echo "4. GATK PrintReads"
			starting=`date +%s`;
			eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e $bam1.{}.real.bam ] && [ -e $bam1.{}.recal.grp ]; then java -XX:+UseParallelGC -XX:ParallelGCThreads="$ParallelGCThreads" -Xmx"$Xmx" -jar "$gatk" -R "$ref" -T PrintReads -nct "$nct" -BQSR "$bam1".{}.recal.grp -I "$bam1".{}.real.bam -o "$bam1".{}.recal.bam -L {}; fi\" &"
			wait
			eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e $bam2.{}.real.bam ] && [ -e $bam2.{}.recal.grp ]; then java -XX:+UseParallelGC -XX:ParallelGCThreads="$ParallelGCThreads" -Xmx"$Xmx" -jar "$gatk" -R "$ref" -T PrintReads -nct "$nct" -BQSR "$bam2".{}.recal.grp -I "$bam2".{}.real.bam -o "$bam2".{}.recal.bam -L {}; fi\" &"
			wait
			end=`date +%s`;
	       		echo "Time elapsed for GATK PrintReads = $(($end-$starting)) seconds"
			echo ""
			#rm -f "$bam1".*.real.bam; # olga
			#rm -f "$bam1".*.recal.grp; # olga
			#rm -f "$bam2".*.real.bam; #olga
			#rm -f "$bam2".*.real.grp; #olga
		fi
	fi

	if [[ $startfrom == 'realign' || $startfrom == 'indelrealign' || $startfrom == 'baserecal' || $startfrom == 'printreads' || $startfrom == 'varcall' ]]; then
		if [[ $variantcaller == 'UnifiedGenotyper' ]]; then
			echo "A. Variant Calling: GATK UnifiedGenotyper"
			starting=`date +%s`;
			if [[ $callmode != 'separate' ]]; then
				if [[ $preprocess == '1' ]]; then
					eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e $bam1.{}.recal.bam ] && [ -e $bam2.{}.recal.bam ]; then java -XX:+UseParallelGC -XX:ParallelGCThreads="$ParallelGCThreads" -Xmx"$Xmx" -jar "$gatk" -R "$ref" -T UnifiedGenotyper -nct "$nct" -o "$bam1".{}.joined.vcf -I "$bam1".{}.recal.bam -I "$bam2".{}.recal.bam "$ugOptions" -L {}; fi\" &"
				else
					eval "cat $partition | parallel --no-notice -j "$cores" \"java -XX:+UseParallelGC -XX:ParallelGCThreads="$ParallelGCThreads" -Xmx"$Xmx" -jar "$gatk" -R "$ref" -T UnifiedGenotyper -nct "$nct" -o "$bam1".{}.joined.vcf -I "$bam1".bam -I "$bam2".bam "$ugOptions" -L {}\" &"
				fi
			
				wait
			else	
				echo ""
				echo "A1. Calling Separated Tumor.VCF and Normal.VCF"
				if [[ $preprocess == '1' ]]; then
					eval "cat $partition | parallel --no-notice -j "$cores" \"java -XX:+UseParallelGC -XX:ParallelGCThreads="$ParallelGCThreads" -Xmx"$Xmx" -jar "$gatk" -R "$ref" -T UnifiedGenotyper -nct "$nct" -o "$bam1".{}.tumor.vcf -I "$bam1".{}.recal.bam "$ugOptions" -L {}\" &"
					wait
					eval "cat $partition | parallel --no-notice -j "$cores" \"java -XX:+UseParallelGC -XX:ParallelGCThreads="$ParallelGCThreads" -Xmx"$Xmx" -jar "$gatk" -R "$ref" -T UnifiedGenotyper -nct "$nct" -o "$bam1".{}.normal.vcf -I "$bam2".{}.recal.bam "$ugOptions" -L {}\" &"
					wait
				else
					eval "cat $partition | parallel --no-notice -j "$cores" \"java -XX:+UseParallelGC -XX:ParallelGCThreads="$ParallelGCThreads" -Xmx"$Xmx" -jar "$gatk" -R "$ref" -T UnifiedGenotyper -nct "$nct" -o "$bam1".{}.tumor.vcf -I "$bam1".bam "$ugOptions" -L {}\" &"
					wait
					eval "cat $partition | parallel --no-notice -j "$cores" \"java -XX:+UseParallelGC -XX:ParallelGCThreads="$ParallelGCThreads" -Xmx"$Xmx" -jar "$gatk" -R "$ref" -T UnifiedGenotyper -nct "$nct" -o "$bam1".{}.normal.vcf -I "$bam2".bam "$ugOptions" -L {}\" &"
					wait
				fi
			fi
			end=`date +%s`;
			echo "Time elapsed for GATK UnifiedGenotyper = $(($end-$starting)) seconds"
			echo ""
		elif [[ $variantcaller == 'samtools' ]]; then
			echo "A. Variant Calling: Samtools"
			starting=`date +%s`;
			if [[ $preprocess == '1' ]]; then
				eval "cat $partition | parallel --no-notice -j "$cores" \"samtools mpileup "$samtoolsOptions" -DSguf "$ref" -r {} "$bam1".{}.recal.bam "$bam2".{}.recal.bam | bcftools view -bvcgI -p 1 - > tmp."$bam1".{}.joined.bcf\" &"
				wait
			else
				eval "cat $partition | parallel --no-notice -j "$cores" \"samtools mpileup "$samtoolsOptions" -DSguf "$ref" -r {} "$bam1".bam "$bam2".bam | bcftools view -bvcgI -p 1 - > tmp."$bam1".{}.joined.bcf\" &"
				wait
			fi
			eval "cat $partition | parallel --no-notice -j "$cores" \"bcftools view -vcg -p 1 tmp."$bam1".{}.joined.bcf > "$bam1".{}.joined.vcf\" &"
			wait
			eval "cat $partition | parallel --no-notice -j "$cores" \"rm -f tmp."$bam1".{}.joined.bcf\" &"
			wait
			if [[ $callmode == 'separate' ]]; then
				echo ""
				echo "A1. Calling Separated Tumor.VCF and Normal.VCF"
				if [[ $preprocess == '1' ]]; then
					eval "cat $partition | parallel --no-notice -j "$cores" \"samtools mpileup "$samtoolsOptions" -DSuf "$ref" -r {} "$bam1".{}.recal.bam | bcftools view -bvcgI -p 1 - > tmp."$bam1".{}.tumor.bcf\" &"
					eval "cat $partition | parallel --no-notice -j "$cores" \"samtools mpileup "$samtoolsOptions" -DSuf "$ref" -r {} "$bam2".{}.recal.bam | bcftools view -bvcgI -p 1 - > tmp."$bam1".{}.normal.bcf\" &"
					wait
				else
					eval "cat $partition | parallel --no-notice -j "$cores" \"samtools mpileup "$samtoolsOptions" -DSuf "$ref" -r {} "$bam1".bam | bcftools view -bvcgI -p 1 - > tmp."$bam1".{}.tumor.bcf\" &"
					eval "cat $partition | parallel --no-notice -j "$cores" \"samtools mpileup "$samtoolsOptions" -DSuf "$ref" -r {} "$bam2".bam | bcftools view -bvcgI -p 1 - > tmp."$bam1".{}.normal.bcf\" &"
					wait
				fi
				eval "cat $partition | parallel --no-notice -j "$cores" \"bcftools view -vcg -p 1 tmp."$bam1".{}.tumor.bcf > "$bam1".{}.tumor.vcf\" &"
				eval "cat $partition | parallel --no-notice -j "$cores" \"bcftools view -vcg -p 1 tmp."$bam1".{}.normal.bcf > "$bam1".{}.normal.vcf\" &"
				wait
				eval "cat $partition | parallel --no-notice -j "$cores" \"rm -f tmp."$bam1".{}.tumor.bcf\" &"
				eval "cat $partition | parallel --no-notice -j "$cores" \"rm -f tmp."$bam1".{}.normal.bcf\" &"
				wait
			fi
			end=`date +%s`;
			echo "Time elapsed for Samtools VCF = $(($end-$starting)) seconds"
			echo ""
		fi
	fi
	if [[ $startfrom == 'realign' || $startfrom == 'indelrealign' || $startfrom == 'baserecal' || $startfrom == 'printreads' || $startfrom == 'varcall' || $startfrom == 'germline' ]]; then
		echo "B. Germlines Filtering"
		starting=`date +%s`;
		if [[ $callmode == 'separate' ]]; then
			echo ""
			echo "B1. Finding Somatic SNPs = SNPs in Tumor but not in Normal..."
			eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e "$bam1".{}.tumor.vcf ] && [ -e $bam1.{}.normal.vcf ]; then python "$somac"/filtersomatic.py <(grep -v '#' "$bam1".{}.tumor.vcf | grep '"$vcfSeparateFilter"' | bash "$somac"/reduce.sh "$minNormalQUAL") <(grep -v '#' $bam1.{}.normal.vcf | bash "$somac"/reduce.sh "$minNormalQUAL") > $bam1.{}.red.pos; fi\" &"
			#eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e "$bam1".{}.tumor.vcf ] && [ -e $bam1.{}.normal.vcf ]; then python "$somac"/filtersomatic.py <(grep -v '#' "$bam1".{}.tumor.vcf | grep '"$vcfSeparateFilter"' | bash "$somac"/reduce.sh "$minNormalQUAL") <(grep -v '#' $bam1.{}.normal.vcf | bash "$somac"/reduce.sh "$minNormalQUAL") > $bam1.{}.red.pos; fi\" &"
			wait
			echo ""
			#echo "B2. Finding extra Somatic SNPs in Joined VCF..."
			#eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e "$bam1".{}.joined.vcf ] && [ -e $bam1.{}.red.pos ]; then python "$somac"/filtersomatic.py <(grep -v '#' "$bam1".{}.joined.vcf | grep '$vcfJoinedFilter' | bash "$somac"/printpos.sh) "$bam1".{}.red.pos > "$bam1".{}.red.pos1; fi\" &"
			#wait
			#eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e "$bam1".{}.red.pos1 ]; then cat "$bam1".{}.red.pos1 >> "$bam1".{}.red.pos; fi\" &"
			#wait
			#echo ""
			#echo "B3. Recreate VCF containing only alleged Somatic SNPs"
			eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e "$bam1".{}.tumor.vcf ] && [ -e $bam1.{}.red.pos ]; then python "$somac"/getVCF.py "$bam1".{}.red.pos "$bam1".{}.tumor.vcf > "$bam1".{}.vcf; fi\" &"
			wait
			#eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e "$bam1".{}.joined.vcf ] && [ -e $bam1.{}.red.pos1 ]; then python "$somac"/getVCF.py "$bam1".{}.red.pos1 "$bam1".{}.joined.vcf >> "$bam1".{}.vcf; fi\" &"
			
			#wait
		else
			echo ""
			echo "B1. Filtering the Joined VCF..."
			eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e "$bam1".{}.joined.vcf ]; then grep -v '#' "$bam1".{}.joined.vcf | grep '$vcfJoinedFilter' > "$bam1".{}.vcf; fi\" &"
			wait
		fi
		end=`date +%s`;
		echo "Time elapsed for Germline Filtering = $(($end-$starting)) seconds"
		echo ""
	fi
	if [[ $startfrom == 'realign' || $startfrom == 'indelrealign' || $startfrom == 'baserecal' || $startfrom == 'printreads' || $startfrom == 'varcall' || $startfrom == 'germline' || $startfrom == 'pileup' ]]; then
		echo "C. Get Positions of VCF for Pileup"
		starting=`date +%s`;
		eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e "$bam1".{}.vcf ]; then cat "$bam1".{}.vcf | bash "$somac"/awkpos.sh > "$bam1".{}.pos; fi\" &"
		wait
		end=`date +%s`;
		#rm -f "$bam1".*.tumor.bam; #olga
		#rm -f "$bam2".*.normal.bam; #olga
		
		echo ""
		echo "D. Pileup"
		starting=`date +%s`;
		if [[ $preprocess == '1' ]]; then
			eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e "$bam1".{}.recal.bam ] && [ -e $bam2.{}.recal.bam ]; then samtools mpileup -f "$ref" -l "$bam1".{}.pos "$samtoolsOptions" -s "$bam1".{}.recal.bam "$bam2".{}.recal.bam > "$bam1".{}.pileup; fi\" &"
			wait
		else
			eval "cat $partition | parallel --no-notice -j "$cores" \"samtools mpileup -f "$ref" -l "$bam1".{}.pos "$samtoolsOptions" -s "$bam1".bam "$bam2".bam -r {} > "$bam1".{}.pileup\" &"
			wait
		fi
		end=`date +%s`;
		#rm -f "$bam1".*.pos; #olga
		echo "Time elapsed for Pileup = $(($end-$starting)) seconds"
		echo ""
	fi
	if [[ $startfrom == 'realign' || $startfrom == 'indelrealign' || $startfrom == 'baserecal' || $startfrom == 'printreads' || $startfrom == 'varcall' || $startfrom == 'germline' || $startfrom == 'pileup' || $startfrom == 'snvcount'  ]]; then
		echo "E. SNVCount"
		starting=`date +%s`;
		eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e "$bam1".{}.pileup ]; then python "$somac"/pileup_count.py -m -i "$bam1".{}.pileup -o "$bam1".{}.snvcount.txt; fi\" &"
		wait
		end=`date +%s`;
		echo "Time elapsed for SNVCount = $(($end-$starting)) seconds"
		echo ""
		#rm -f "$bam1".*.pileup; #olga
	fi
	if [[ $startfrom == 'realign' || $startfrom == 'indelrealign' || $startfrom == 'baserecal' || $startfrom == 'printreads' || $startfrom == 'varcall' || $startfrom == 'germline' || $startfrom == 'pileup' || $startfrom == 'snvcount'  || $startfrom == 'chi2' ]]; then
		echo "F. Chi2 Counting"
		starting=`date +%s`;
		eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e "$bam1".{}.snvcount.txt ]; then bash "$somac"/chisq.sh file="$bam1".{}.snvcount.txt minmq="$minmq" minbq="$minbq"; fi\" &"
		wait
		end=`date +%s`;
		echo "Time elapsed for Chi2 Counting = $(($end-$starting)) seconds"
		echo ""
	fi
	if [[ $startfrom == 'realign' || $startfrom == 'indelrealign' || $startfrom == 'baserecal' || $startfrom == 'printreads' || $startfrom == 'varcall' || $startfrom == 'germline' || $startfrom == 'pileup' || $startfrom == 'snvcount'  || $startfrom == 'chi2' || $startfrom == 'VAF' ]]; then
		echo "G. Calculating LRT, VAF, etc"
		starting=`date +%s`;
		eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e "$bam1".{}.snvcount.txt ]; then R --vanilla "$bam1".{}.snvcount.txt "$bam1".{}.extra < $somac/extracol.R; fi\" &"
		wait
		end=`date +%s`;
		echo "Time elapsed for calculating LRT, VAF, etc = $(($end-$starting)) seconds"
		echo ""
	fi
	if [[ $startfrom == 'realign' || $startfrom == 'indelrealign' || $startfrom == 'baserecal' || $startfrom == 'printreads' || $startfrom == 'varcall' || $startfrom == 'germline' || $startfrom == 'pileup' || $startfrom == 'snvcount'  || $startfrom == 'chi2' || $startfrom == 'VAF' || $startfrom == 'FDR' ]]; then
		
		echo "H. Calculating FDR"
		starting=`date +%s`;
		eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e "$bam1".{}.extra ] && [ -e "$bam1".{}.chisquare.txt ]; then python $somac/create_statdata.py "$bam1".{}.vcf "$bam1".{}.chisquare.txt "$bam1".{}.extra > "$bam1".{}.temp; fi\" &"
		wait
		eval "cat $partition | parallel --no-notice -j "$cores" \"if [ -e "$bam1".{}.temp ]; then R --vanilla "$bam1".{}.temp "$bam1".{}.testset < $somac/fdr.R; fi\" &"
		wait
		head -1 $(ls -m1 "$bam1".*.testset | head -1) > "$bam1".statistics
		for i in "$bam1"*.testset; do tail -n +2 "$i" >> "$bam1".statistics; done
		wait
		end=`date +%s`;
		#rm -f ${bam1%/*}/*.testset
		#rm -f "$bam1".*.chisquare.txt; #olga
		#rm -f "$bam1".*.extra; #olga
	fi
	if [[ $startfrom == 'realign' || $startfrom == 'indelrealign' || $startfrom == 'baserecal' || $startfrom == 'printreads' || $startfrom == 'varcall' || $startfrom == 'germline' || $startfrom == 'pileup' || $startfrom == 'snvcount'  || $startfrom == 'chi2' || $startfrom == 'VAF' || $startfrom == 'FDR' || $startfrom == 'combineVCF' ]]; then
		echo "I. Merging filtered .vcf file"
		starting=`date +%s`;
		for i in "$bam1".*vcf; do if [[ $i != *normal.vcf ]] && [[ $i != *tumor.vcf ]]; then cat $i >> "$bam1".combine.tmp.vcf; fi; done
		cat $somac/headerVCF.txt "$bam1".combine.tmp.vcf > "$bam1".combine.vcf 
		rm "$bam1".combine.tmp.vcf
		end=`date +%s`;
		echo "Time elapsed for combining VCF file = $(($end-$starting)) seconds"
	fi

	if [[ $startfrom == 'realign' || $startfrom == 'indelrealign' || $startfrom == 'baserecal' || $startfrom == 'printreads' || $startfrom == 'varcall' || $startfrom == 'germline' || $startfrom == 'pileup' || $startfrom == 'snvcount'  || $startfrom == 'chi2' || $startfrom == 'VAF' || $startfrom == 'FDR' || $startfrom == 'combineVCF' || $startfrom == 'RData' ]]; then
		echo "J. Creating RData"
		starting=`date +%s`;
		R --vanilla "$bam1".statistics "$bam1".RData < $somac/convertToR.R
		end=`date +%s`;
		echo "Time elapsed for combining VCF file = $(($end-$starting)) seconds"
	fi
	if [[ $startfrom == 'realign' || $startfrom == 'indelrealign' || $startfrom == 'baserecal' || $startfrom == 'printreads' || $startfrom == 'varcall' || $startfrom == 'germline' || $startfrom == 'pileup' || $startfrom == 'snvcount'  || $startfrom == 'chi2' || $startfrom == 'VAF' || $startfrom == 'FDR' || $startfrom == 'combineVCF' || $startfrom == 'RData' || $startfrom == 'cleanup' ]]; then
		echo "K. Cleaning up"
		
		rm "$bam1"*.intervals
		rm "$bam2"*.intervals
		rm "$bam1"*.recal.grp
		rm "$bam2"*.recal.grp
		rm "$bam1"*.recal.bam
		rm "$bam2"*.recal.bam
		rm "$bam1"*.recal.bai
		rm "$bam2"*.recal.bai
		rm "$bam1"*.real.bam
		rm "$bam2"*.real.bai
	
		rm "$bam1"*tumor.vcf
		rm "$bam1"*normal.vcf
		rm "$bam1".*vcf.idx
		for i in "$bam1"*.vcf; do if [ $i != "$bam1".combine.vcf ]; then rm $i; fi; done
		
		rm "$bam1"*.pileup
		rm "$bam1"*.pos
	
		rm "$bam1"*.snvcount.txt
		rm "$bam1"*.chisquare.txt
		rm "$bam1"*.temp
		rm "$bam1"*.testset
		rm "$bam1"*.extra
			
	fi
fi
