library(OCplus)


#############################################################
## pileup count txt file -> N*8 count table after filtering of base/mapping qual. 
## This input file (.txt) is produced by using "pileup_count.py" 

MakingCount<-function(file="snvcount.txt", bq=0, mq=0){

            ## Step 1:
            ## Reading the count data from (We made txt file following pipeline, Bam->mpileup->python->txt) 
            
            py<-read.table(file, sep="\t", fill=TRUE, row.names=NULL,header=TRUE,stringsAsFactors=FALSE)
            cname<-colnames(py)[-1]
            py<-py[,-dim(py)[2]]
            colnames(py)<-cname; rm(cname)
            rownames(py) <- apply(py[,c("chr", "bp")], 1, function(x) paste(x[1], ".", as.numeric(x[2]), sep=""))
            
            
            ## Step 2: 
            ## Find the snv positions which have nonzero counts in both py and vcf
             
            both<-is.na(py[,'coverage_1'])==FALSE &  is.na(py[,'coverage_2'])==FALSE
            py2<-py[both,]
            
            #######################################################
            ## py2-> AGCT Table
            
            
            py.table.0<- apply(py2[,
            c('Aph_1','Gph_1','Cph_1','Tph_1',   
            'Aph2_1','Gph2_1','Cph2_1','Tph2_1',
            'Aph_2','Gph_2','Cph_2','Tph_2',   
            'Aph2_2','Gph2_2','Cph2_2','Tph2_2')], 1, function(x) strsplit(x, ';'))
            
            q.filter<-function(x,bq, mq){
                c(sum(as.numeric(x[[1]])>=bq&as.numeric(x[[5]])>=mq),
                sum(as.numeric(x[[2]])>=bq&as.numeric(x[[6]])>=mq),
                sum(as.numeric(x[[3]])>=bq&as.numeric(x[[7]])>=mq),
                sum(as.numeric(x[[4]])>=bq&as.numeric(x[[8]])>=mq),
                sum(as.numeric(x[[9]])>=bq&as.numeric(x[[13]])>=mq),
                sum(as.numeric(x[[10]])>=bq&as.numeric(x[[14]])>=mq),
                sum(as.numeric(x[[11]])>=bq&as.numeric(x[[15]])>=mq),
                sum(as.numeric(x[[12]])>=bq&as.numeric(x[[16]])>=mq)
                )
            }
            
            py.table<- t(sapply(py.table.0, q.filter, bq=bq ,mq=mq))
            ##
            ## py.table<-py2[,]
            
            colnames(py.table)<-c('tA','tG','tC','tT', 'nA','nG','nC','nT')
            
            py.table<-data.frame(py2$ref,py.table)
            
            ref.var<-function(x0){
                ref<-x0[1]
                x<-as.numeric(x0[-1])
                Allele<-c("A","G","C","T")
                temp<-x[1:4]+x[5:8]
                idx<-order(temp,decreasing=TRUE)
                R.allele<-Allele[idx]
                ref.idx<-which(R.allele==ref)
                
                if (ref.idx==1){REF<-R.allele[1]; VAR<-R.allele[2]; 
                    count<-c(x[idx[1]], x[idx[2]], x[idx[1]+4],  x[idx[2]+4])}
                if (ref.idx!=1){REF<-R.allele[ref.idx]; VAR<-R.allele[1]; 
                    count<-c(x[idx[ref.idx]], x[idx[1]], x[idx[ref.idx]+4], x[idx[1]+4])}   
            
            c(REF,VAR,count)    
            }
            
            aaa<-data.frame(t(apply(py.table,1, ref.var)),stringsAsFactors=FALSE)
            colnames(aaa)<-c("ref","var","t1","t2","n1","n2")
            Count<-transform(aaa, t1=as.numeric(t1),t2=as.numeric(t2),n1=as.numeric(n1),n2=as.numeric(n2))
            
            
            
            return(list(raw=py2,Count=Count))

}


logit<-function(x){
    log(x/(1-x))
}

frac<-function(x){exp(x)/(1+exp(x))}




## Chi2 method 


ChisqTest<- function (Count, version=2) {
    dt<-as.matrix(Count[,3:6])
    # For only 2*2 table (see wikipedia)
    obs <- dt
    N <- rowSums(dt)
    aa <- dt[,1]
    bb <- dt[,2]
    cc <- dt[,3]
    dd <-dt[,4]
    
    rsum1<-aa+bb
    rsum2<-cc+dd
    csum1<-aa+cc
    csum2<-bb+dd

    temp<-abs(aa*dd-bb*cc)-N/2
    
    chisq.val<- N*temp^2/rsum1/rsum2/csum1/csum2

    if (version==2){chisq.val[temp<0]<-0}
    chisq.val[chisq.val==Inf] <- NA
    p.val <- 1-pchisq(chisq.val, df= 1)
    return (data.frame(chisq.val,p.val ))
}




## fdr2d method 

somac<-function(Count, method="chi2", nr=15, nperm=100, smooth=0.2){

    N<-dim(Count)[1] ## number of snvs
    n1<-rowSums(Count[,3:4]) ## number of coverage in Tumor
    n2<-rowSums(Count[,5:6]) ## number of coverage in Normal
    nn<-n1+n2 ## Total coverage
    

    ft<-Count[,4]/n1; fn<-Count[,6]/n2

    aaa<-(logit(ft)+logit(fn))/2
    Z<-zstar<-chi2s<-NULL

    temp<-seq(min(aaa)-0.1,max(aaa)+0.1,,10)
    add<-temp[2]-temp[1]
    
    if (method=="chi2"){ chi2<-ChisqTest(Count) }
    
    
        for ( i in temp[-10]){

                idx<- aaa>i  & aaa < i+add & aaa !=Inf & aaa !=-Inf & is.na(aaa)==FALSE 


                Z0<-cbind(logit(fn[idx]),logit(ft[idx]))
                #Z0<-Z0+matrix(rnorm(length(Z0),0,0.001),nrow(Z0),ncol(Z0)) # Add-hoc! add the small error


                xbreaks = MidBreaks(Z0[, 1], nr)
                ybreaks = MidBreaks(Z0[, 2], nr)
                xmid = brk2mid(xbreaks)
                ymid = brk2mid(ybreaks)
    
  
                ng<-nrow(Z0)

                error<-Z0[,2] - aaa[idx]
                Z<-rbind(Z,Z0); 
                
                
                if (method=="fdr2d"){
                zstar0 = matrix(0, nrow = ng * nperm, ncol = 2)
       
                            for (j in 1:nperm) {
                                ##cat("\t", j, "\n")
                                err_n = sample(error)
                                err_t = sample(error)
                        
                                etan.new<-aaa[idx]+ err_n
                                etat.new<- aaa[idx]+ err_t 
            
                                zstar0[((j - 1) * ng + 1):(j * ng), 1:2] = cbind(etat.new, etan.new)        
                            }
                zstar<-rbind(zstar,zstar0)
                }
                
                if (method == "chi2"){
                                                    chi2s<-rbind(chi2s,chi2[idx,])
                }
                
        }

    if (method=="fdr2d"){
                        xbreaks = MidBreaks(Z[, 1], nr)
                        ybreaks = MidBreaks(Z[, 2], nr)
                        xmid = brk2mid(xbreaks)
                        ymid = brk2mid(ybreaks)
                        
                       cut.stat.x = cut(c(Z[, 1], zstar[, 1]), xbreaks, include.lowest = TRUE)
                        cut.stat.y = cut(c(Z[, 2], zstar[, 2]), ybreaks, include.lowest = TRUE)
                        cut.null.x = cut(zstar[, 1], xbreaks, include.lowest = TRUE)
                        cut.null.y = cut(zstar[, 2], ybreaks, include.lowest = TRUE)
                        tab.stat = table(cut.stat.x, cut.stat.y)
                        tab.null = table(cut.null.x, cut.null.y)
                        df.smooth = (1 - smooth) * (nr - 1)^2
                        b = smooth2d.direct(tab.null, tab.stat, df = df.smooth)
                        f0fz = b$fit/((1 - b$fit) * nperm)
                     
                     ## estimation of p0
                             zndx = findInterval(0, xbreaks)
                            nn = length(ybreaks)
                            mndx = floor(nn/4):ceiling(3 * nn/4)
                            p0 = min(1/f0fz[zndx, mndx])
                        
                           p0.est = TRUE
                            
                     fdr = p0 * f0fz
                     #fdr<-fdr/max(fdr)      
 
     ifdr = approx2d(xmid, ymid, fdr, Z[, 1], Z[, 2])
     Z[,1]<-frac(Z[,1])
     Z[,2]<-frac(Z[,2])
    ret = data.frame(cbind(Z, ifdr))            
    
    param = list(p0 = p0, p0.est = p0.est, fdr = fdr, xbreaks = xbreaks, 
        ybreaks = ybreaks)
    attr(ret, "param") = param

    }
    if (method=="chi2"){
        Z[,1]<-frac(Z[,1])
        Z[,2]<-frac(Z[,2])
        ret =data.frame(cbind(Z,chi2s[,2]))
    }

return(ret)


}

plot.fdr2d.result<-function (x, levels, nr.plot = 20, add = FALSE, grid = FALSE, 
    pch = ".", xlab, ylab, vfont = c("sans serif", "plain"), 
    lcol = "black", ...) 
{
    if (missing(levels)) 
        levels = c(0.05, 0.1, 0.2, 0.3)
    if (missing(xlab)) 
        xlab = colnames(x)[1]
    if (missing(ylab)) 
        ylab = colnames(x)[2]
    p = attr(x, "param")
    if (add) {
        points(x[, 1], x[, 2], pch = pch, ...)
    }
    else {
        plot(x[, 1], x[, 2], xlab = xlab, ylab = ylab, pch = pch, 
            ...)
    }
    cfdr = list()
    if (nr.plot < 1) {
        cfdr$x = brk2mid(p$xbreaks)
        cfdr$y = brk2mid(p$ybreaks)
        cfdr$z = p$fdr
    }
    else {
        xo = seq(min(x[, 1]), max(x[, 1]), len = nr.plot)
        yo = seq(min(x[, 2]), max(x[, 2]), len = nr.plot)
        cfdr = interp(x[, 1], x[, 2], x[, 3], xo, yo, duplicate="mean")
    }
    contour(cfdr, add = TRUE, col = lcol, levels = levels, vfont = vfont)
    if (grid) {
        abline(v = p$xbreaks, lty = 3)
        abline(h = p$ybreaks, lty = 3)
    }
    invisible(x)
}

LRT<-function(y,n,f0,f1){
  
  l0<-y*log(f0/(1-f0)) +n*log(1-f0)
  #if (f1!=0){
  l1<-f1
  l1[f1!=0]<-y*log(f1/(1-f1)) +n*log(1-f1)
  l1[f1==0]<-0
  #}
  #else {
  #l1<-0
  #}
  LRT<- -2*(l0-l1)
  
  return(LRT)

  
}

ROC<-function(tab) {

  TPR<-tab[2,2]/sum(tab[2,])
  FPR<-tab[1,2]/sum(tab[1,])
  FDR<-tab[1,2]/sum(tab[,2])
  FNR<-tab[2,1]/sum(tab[,1])
  
  return(list(sens=round(TPR,3),spec=1-round(FPR,3),FDR=round(FDR,3),FNR=round(FNR,3)))
  
}



## fdr2d method 

somac.fdr<-function(Count, nr=15, nperm=100, smooth=0.2){
  

  
  y_T<-Count$n2
  n_T<-Count$n1+Count$n2
  y_N<-Count$t2
  n_N<-Count$t1+Count$t2

  LRT_T<-LRT(y_T, n_T,f0=(0.5/n_T),f1=(y_T/n_T))
  LRT_N<-LRT(y_N, n_N,f0=(0.5/n_N),f1=(y_N/n_N))
  Z<-cbind(LRT_T,LRT_N)
  
  N<-dim(Z)[1] 
  K<-dim(Z)[2]
  zstar<-matrix(0, (N*nperm),K)
  
  p.c<-(y_T+y_N)/(n_T+n_N) ## MLE under Null

  for (cnt in 1:nperm) {
        set.seed(cnt)
        # cat("\t", cnt, "\n")
        y_T.new<-rbinom(N,n_T,p.c)+0.5
        y_N.new<-rbinom(N,n_N,p.c)+0.5
        
        LRT_T.new<-LRT(y_T.new,n_T,f0=(0.5/n_T),f1=(y_T.new/n_T))
        LRT_N.new<-LRT(y_N.new,n_N,f0=(0.5/n_N),f1=(y_N.new/n_N))
        
        zstar[((cnt-1)*N+1):(cnt*N),]<-cbind(LRT_T.new,LRT_N.new)
        
  }

    xbreaks = MidBreaks(Z[, 1], nr)
    ybreaks = MidBreaks(Z[, 2], nr)
    xmid = brk2mid(xbreaks)
    ymid = brk2mid(ybreaks)
    
    cut.stat.x = cut(c(Z[, 1], zstar[, 1]), xbreaks, include.lowest = TRUE)
    cut.stat.y = cut(c(Z[, 2], zstar[, 2]), ybreaks, include.lowest = TRUE)
    cut.null.x = cut(zstar[, 1], xbreaks, include.lowest = TRUE)
    cut.null.y = cut(zstar[, 2], ybreaks, include.lowest = TRUE)
    tab.stat = table(cut.stat.x, cut.stat.y)
    tab.null = table(cut.null.x, cut.null.y)
    df.smooth = (1 - smooth) * (nr - 1)^2
    b = smooth2d.direct(tab.null, tab.stat, df = df.smooth)
    f0fz = b$fit/((1 - b$fit) * nperm)
    
    ## estimation of p0
    zndx = findInterval(0, xbreaks)
    nn = length(ybreaks)
    mndx = floor(nn/4):ceiling(3 * nn/4)
    p0 = min(1/f0fz[zndx, mndx])
    
    p0.est = TRUE
    
    fdr = p0 * f0fz
    fdr<-fdr/max(fdr)      
    
    ifdr = approx2d(xmid, ymid, fdr, Z[, 1], Z[, 2])
    ret = data.frame(cbind(Z, ifdr))            
    rownames(ret)<-rownames(Count)
    param = list(p0 = p0, p0.est = p0.est, fdr = fdr, xbreaks = xbreaks, 
                 ybreaks = ybreaks)
    attr(ret, "param") = param
    
    attr(ret, "zstar") = zstar
  
   
  return(ret)
  
  
}



